@@ -166,10 +166,6 @@ class Graph(Resource):
             (o and _o == o):
                 self.triples.remove((_s,_p,_o))
 
-    def remove_triples(self, *triples:tuple):
-        for triple in triples:
-            self.triples.remove(triple)
-
     def remove_triples(self, triples:set):
         for triple in triples:
             self.triples.remove(triple)
@@ -184,6 +180,21 @@ class Graph(Resource):
             dictionary[str(s)][str(p)].add(o)
         return dictionary
 
+    def to_resources(self, s = None, p:URIRef = None, o = None):
+        rs = set()
+        for _s,_p,_o in self.triples:
+            if (not(s) and not(p) and not(o)) or \
+            (s and _s == s) or \
+            (p and _p == p) or \
+            (o and _o == o):
+                if not rs:
+                    rs.add(Resource())
+                for resource in rs:
+                    if _s == resource.uri:
+                        resource.add_value(str(_p), str(o))
+        return rs
+    resources = property(to_dict)
+
     def update_triples(self, new_triple:tuple, old_triple:tuple):
         self.triples.remove(old_triple)
         self.triples.add(new_triple)
@@ -210,4 +221,7 @@ class Graph(Resource):
                     result += '\n  - ' + str(p)
                     for o in triples[s][p]:
                         result += '\n   - ' + str(o)
-        return result
\ No newline at end of file
+        return result
+
+g = Graph(triples = {(SMTK.subject, SMTK.predicate, SMTK.object)})
+print(g.to_resources())
\ No newline at end of file
